/*
 * LICENCE[[
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1/CeCILL 2.O 
 *
 * The contents of this file are subject to the Mozilla Public License Version 
 * 1.1 (the "License"); you may not use this file except in compliance with 
 * the License. You may obtain a copy of the License at http://www.mozilla.org/MPL/ 
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, 
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License 
 * for the specific language governing rights and limitations under the 
 * License. 
 * 
 * The Original Code is utc.fr code. 
 * 
 * The Initial Developer of the Original Code is 
 * david.rivron@utc.fr
 * 
 * Portions created by the Initial Developer are Copyright (C) 2012
 * the Initial Developer. All Rights Reserved. 
 * 
 * Contributor(s): 
 * 
 * 
 * Alternatively, the contents of this file may be used under the terms of 
 * either of the GNU General Public License Version 2 or later (the "GPL"), 
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"), 
 * or the CeCILL Licence Version 2.0 (http://www.cecill.info/licences.en.html), 
 * in which case the provisions of the GPL, the LGPL or the CeCILL are applicable 
 * instead of those above. If you wish to allow use of your version of this file 
 * only under the terms of either the GPL or the LGPL, and not to allow others 
 * to use your version of this file under the terms of the MPL, indicate your 
 * decision by deleting the provisions above and replace them with the notice 
 * and other provisions required by the GPL or the LGPL. If you do not delete 
 * the provisions above, a recipient may use your version of this file under 
 * the terms of any one of the MPL, the GPL, the LGPL or the CeCILL.
 * ]]LICENCE
 */
 
 var MessagesHandler = require('./MessagesHandler.js'),
	util = require('util');
/**
 * Handler d'un message de type 'dialog'.
 * 
 * Permet à un client d'envoyer un message à un autre client
 * 
 * Propriétés obligatoires du message
 * {
 * 	dialogType: <sous-type caractérisant le dialogue>
 * 	destClientId: <id du client destinataire du message>
 * 	wspCd: <code de l'atelier sur lequel vérifier les droits>
 * }
 * 
 * Propriétés optionnelles du message
 * {
 * 	admin: <booléen indiquant si le dialogue requiert la permissions d'admin
 * 	fromDialogId: <id du dialogue auquel le message répond>
 * 	...: <propriétés spécifiques à ce type de dialogue>
 * }
 */
	
var DialogMessagesHandler = module.exports = function (pCollabServer) {
	MessagesHandler.call(this, 'dialog', pCollabServer);
}

util.inherits(DialogMessagesHandler, MessagesHandler);

DialogMessagesHandler.prototype.onMessage = function (pClient, pMessage) {
	if (!pMessage.dialogType || !pMessage.destClientId) return;
	if (!pMessage.wspCd && !pMessage.fromDialogId) pMessage.admin = true;
	this.server.requirePerm(pClient, pMessage.wspCd, pMessage.admin ? MessagesHandler.ADMIN_PERM : MessagesHandler.DIALOG_PERM, function () {
		this.xHandleMessage(pClient, pMessage);
	}.bind(this));
}

DialogMessagesHandler.prototype.xHandleMessage = function (pClient, pMessage) {
	var vDestClient = this.server.clients[pMessage.destClientId];
	pMessage.account = pClient.account;
	if (vDestClient) this.server.sendMessage(vDestClient, pMessage.wspCd || '', pMessage);
}